@@ -24,6 +24,7 @@
 
 #include "support.h"
 #include "recipe_win.h"
+#include "load_data.h"
 
 /* A minimalist main.c */
 gint
@@ -40,6 +41,7 @@ main( int argc, char *argv[])
 
 	glade_gnome_init();
 
+	/* this passes control to the progress bar. */
 	gtk_idle_add( on_idle_in_main, dummy);
 
 	gtk_main();
