@@ -35,19 +35,20 @@
 static void 
 compute_percent_nutrient_goal( void);
 
+static GladeXML *xml = NULL;
+
 /* Display the nutrition composition dialog. */
 void
 display_nutrient_dialog()
 {
 	GtkWidget *entry, *nutr_comp_win;
-	GladeXML *xml = gnutr_ret_xml();
 	gchar *text;
+
 	Recipe_t *recipe = gnutr_ret_recipe();
 
 	/* The nutrient values. */
 
 	/* macro-nutrients. */
-
 	entry = glade_xml_get_widget( xml, "protein_ndlg_entry");
 	text = ftoa( recipe->nutr->total[0]);
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
@@ -89,7 +90,6 @@ display_nutrient_dialog()
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
 
 	/* micro-nutrients. */
-
 	entry = glade_xml_get_widget( xml, "vita_ndlg_entry");
 	text = ftoa( recipe->nutr->total[22]);
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
@@ -376,7 +376,6 @@ display_nutrient_dialog()
 	/* The percentage of the dietary goal. */
 
 	/* macro-nutrients. */
-
 	entry = glade_xml_get_widget( xml, "protein_dg_ndlg_entry");
 	text = ftoa( recipe->nutr->pcnt_goal[0]);
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
@@ -418,7 +417,6 @@ display_nutrient_dialog()
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
 
 	/* micro-nutrients. */
-
 	entry = glade_xml_get_widget( xml, "vita_dg_ndlg_entry");
 	text = ftoa( recipe->nutr->pcnt_goal[22]);
 	gtk_entry_set_text( GTK_ENTRY( entry), text);
@@ -708,7 +706,7 @@ display_nutrient_dialog()
 }
 
 /* compute the percentage of the nutrient goal achieved
- * by the total nutrient values. */
+ * by the nutrient values per serving. */
 static void 
 compute_percent_nutrient_goal()
 {
@@ -724,38 +722,61 @@ compute_percent_nutrient_goal()
 		else
 		{
 			recipe->nutr->pcnt_goal[i] = 100.0 *  recipe->nutr->total[i] / 
-					( recipe->nutr->goal[i] * atof( recipe->no_serv));
+					recipe->nutr->goal[i];
 		}
 	}
+	/* Cys and Met, can be interconverted by hepatic
+	 * enzymes, so RDIs are issued for the total. */
+	if ( recipe->nutr->goal[38] + recipe->nutr->goal[39] != 0)
+	{
+		recipe->nutr->pcnt_goal[38] = 100.0 *
+			( recipe->nutr->total[38] + recipe->nutr->total[39] ) /
+			( recipe->nutr->goal[38] + recipe->nutr->goal[39]);
+		recipe->nutr->pcnt_goal[39] = recipe->nutr->pcnt_goal[38];
+	}
+	/* Same for Tyr and Phe. */
+	if ( recipe->nutr->goal[40] + recipe->nutr->goal[41] != 0)
+	{
+		recipe->nutr->pcnt_goal[40] = 100.0 *
+			( recipe->nutr->total[40] + recipe->nutr->total[41] ) /
+			( recipe->nutr->goal[40] + recipe->nutr->goal[41]);
+		recipe->nutr->pcnt_goal[41] = recipe->nutr->pcnt_goal[40];
+	}
 }
 
 /* When the "Nutrients" button is released in the recipe window, show
  * the nutritional composition dialog. */
 void
-on_mw_nutr_comp_released( GtkButton *button,
-                          gpointer   user_data)
+gnutr_show_nutr_comp_dlg()
 {
-	GladeXML *xml = gnutr_ret_xml();
-	Recipe_t *recipe = gnutr_ret_recipe();
 	Food_t *food;
 	gint i, row = 0;
 	gchar  *amount = NULL;
+	static gboolean loaded_xml = FALSE;
 
-	recipe->ingredient_clist = (GtkCList *)
-			glade_xml_get_widget( xml, "mw_fd_clist");
-	recipe->no_serv = gtk_entry_get_text( GTK_ENTRY(
-			glade_xml_get_widget( xml, "mw_no_serv_entry")));
+	Recipe_t *recipe = gnutr_ret_recipe();
 
-	if ( !all_digits( recipe->no_serv))
+	/* load the glade interface. */
+	if ( !loaded_xml)
 	{
-		GtkWidget *message = glade_xml_get_widget( xml, "nserv_msgbox");
-		gnome_dialog_close_hides( GNOME_DIALOG( message), TRUE);
-		gtk_widget_show( message);
-		return;
+		xml = glade_xml_new( GNUTRITION_GLADEDIR "/nutr_comp_dlg.glade", NULL);
+		loaded_xml = TRUE;
+
+		if (  xml != NULL)
+		{
+			glade_xml_signal_autoconnect( xml);
+		}
+		else
+		{
+			g_log( "Gnutrition", G_LOG_LEVEL_ERROR,
+					"gnutr_show_srch_dlg: cannot load glade file\n");
+			return;
+		}
 	}
 
 	for( i=0; i<NO_NUTR; i++) recipe->nutr->total[i] = 0.0;
 
+	/* compute the total nutrient values for the recipe. */
 	while ( row < recipe->no_ingredients ) 
 	{
 		gtk_clist_get_text( recipe->ingredient_clist, row, 0, &amount);
@@ -766,12 +787,20 @@ on_mw_nutr_comp_released( GtkButton *button,
 		for( i=0; i<NO_NUTR; i++) 
 		{
 			recipe->nutr->total[i] += ( 1.0/ atof( recipe->no_serv)) *
-				( atof( food->nutrs->value[i]) * atof( amount) * 
+				( food->nutrs->value[i] * atof( amount) * 
 				  atof( food->msre[food->sel_msre]->msre_weight) / 100.0);
 		}
 		row++;
 	}
+
+	/* divide the nutrient totals by the number of servings. */
+	for( i=0; i<NO_NUTR; i++) 
+	{
+		recipe->nutr->total[i] /= atof( recipe->no_serv);;
+	}
+
 	compute_percent_nutrient_goal();
+
 	display_nutrient_dialog();
 }
 
@@ -781,7 +810,6 @@ void
 on_ndlg_ok_button_released( GtkButton *button,
                             gpointer   user_data)
 {
-	GladeXML *xml = gnutr_ret_xml();
 	GtkWidget *widget = glade_xml_get_widget( xml, "nutr_comp_dlg");
 	gtk_widget_hide( widget);
 }
