@@ -20,7 +20,7 @@ gchar *
 extract_column( gchar *, gint, gint);
 
 gint
-food_search_match( gchar *, gchar *);
+text_match( gchar *, gchar *);
 
 gchar *
 ftoa( gfloat);
